@@ -1,6 +1,7 @@
 # pylint: disable=undefined-variable
 from .entities import *  # noqa: F403
 from .structures import *  # noqa: F403
+from .utils import *  # noqa: F403
 
 
-__all__ = entities.__all__ + structures.__all__  # noqa: F405
+__all__ = entities.__all__ + structures.__all__ + utils.__all__  # noqa: F405
